pub struct UnsignedVerifiableCredential {
pub context: Vec<Url>,
pub id: Option<Url>,
pub credential_type: Vec<String>,
pub name: Option<LanguageValue>,
pub description: Option<LanguageValue>,
pub issuer: Issuer,
pub credential_subject: Value,
pub valid_from: Option<DateTime<Utc>>,
pub valid_until: Option<DateTime<Utc>>,
pub credential_status: Option<Status>,
pub credential_schema: Option<Vec<CredentialSchema>>,
}Expand description
A Verifiable Credential as defined by the W3C Verifiable Credentials Data Model v2.0 - https://www.w3.org/TR/vc-data-model-2.0 WITHOUT the proof
Fields
context: Vec<Url>id: Option<Url>credential_type: Vec<String>name: Option<LanguageValue>description: Option<LanguageValue>issuer: Issuercredential_subject: Valuevalid_from: Option<DateTime<Utc>>valid_until: Option<DateTime<Utc>>credential_status: Option<Status>credential_schema: Option<Vec<CredentialSchema>>Implementations
Sourceimpl UnsignedVerifiableCredential
impl UnsignedVerifiableCredential
Sourcepub fn sign(
self,
private_key: impl AsRef<[u8]>,
) -> Result<VerifiableCredential, Box<dyn Error>>
pub fn sign( self, private_key: impl AsRef<[u8]>, ) -> Result<VerifiableCredential, Box<dyn Error>>
Sign the Verifiable Credential with a private key. Creates a proof with default values and a custom proofValue.
Sourcepub fn sign_with_schema_check(
self,
private_key: impl AsRef<[u8]>,
schema: &Value,
) -> Result<VerifiableCredential, Box<dyn Error>>
pub fn sign_with_schema_check( self, private_key: impl AsRef<[u8]>, schema: &Value, ) -> Result<VerifiableCredential, Box<dyn Error>>
Sign the Verifiable Credential with a private key. Creates a proof with default values and a custom proofValue. Also performs a JSON schema check on the credentialSubject.
Sourceimpl UnsignedVerifiableCredential
impl UnsignedVerifiableCredential
Sourcepub fn sign_with_schema_check_from_url(
self,
private_key: impl AsRef<[u8]>,
schema_url: &str,
) -> Result<VerifiableCredential, Box<dyn Error>>
pub fn sign_with_schema_check_from_url( self, private_key: impl AsRef<[u8]>, schema_url: &str, ) -> Result<VerifiableCredential, Box<dyn Error>>
Sign the Verifiable Credential with a private key. Creates a proof with default values and a custom proofValue. Also performs a JSON schema check on the credentialSubject. The schema is fetched from a URL.